pub struct Member {
pub name: Option<String>,
pub ty: usize,
pub at: u64,
pub bits: Option<Bits>,
}Expand description
One member of a record.
Fields
name: Option<String>Its name, absent for an anonymous struct or union member and for an unnamed bit-field.
ty: usizeWhich of the unit’s types it is.
at: u64How far into the record it starts, in bytes. Meaningless for a bit-field, which says where
it is in Member::bits instead.
bits: Option<Bits>Which bits it is, for a bit-field, and None for an ordinary member.